:mod:`art.attacks.inference.model_inversion`
============================================
.. automodule:: art.attacks.inference.model_inversion

Model Inversion MIFace
----------------------
.. autoclass:: MIFace
   :members:
   :special-members:
